package com.ruoyi.model.service;

import java.util.List;
import com.ruoyi.model.domain.AppletBanner;

/**
 * 轮播图Service接口
 * 
 * @author ruoyi
 * @date 2025-03-30
 */
public interface IAppletBannerService 
{
    /**
     * 查询轮播图
     * 
     * @param id 轮播图主键
     * @return 轮播图
     */
    public AppletBanner selectAppletBannerById(Long id);

    /**
     * 查询轮播图列表
     * 
     * @param appletBanner 轮播图
     * @return 轮播图集合
     */
    public List<AppletBanner> selectAppletBannerList(AppletBanner appletBanner);

    /**
     * 新增轮播图
     * 
     * @param appletBanner 轮播图
     * @return 结果
     */
    public int insertAppletBanner(AppletBanner appletBanner);

    /**
     * 修改轮播图
     * 
     * @param appletBanner 轮播图
     * @return 结果
     */
    public int updateAppletBanner(AppletBanner appletBanner);

    /**
     * 批量删除轮播图
     * 
     * @param ids 需要删除的轮播图主键集合
     * @return 结果
     */
    public int deleteAppletBannerByIds(Long[] ids);

    /**
     * 删除轮播图信息
     * 
     * @param id 轮播图主键
     * @return 结果
     */
    public int deleteAppletBannerById(Long id);
}
